@@ -1,5 +1,5 @@
 """
-Geometry factories based on the geo interface.
+Geometry factories based on the geo interface
 """
 
 from point import Point, asPoint
@@ -7,7 +7,7 @@ from linestring import LineString, asLineString
 from polygon import Polygon, asPolygon
 from multipoint import MultiPoint, asMultiPoint
 from multilinestring import MultiLineString, asMultiLineString
-from multipolygon import MultiPolygon, asMultiPolygon
+from multipolygon import MultiPolygon, MultiPolygonAdapter, asMultiPolygon
 
 
 def shape(context):
@@ -30,9 +30,9 @@ def shape(context):
     elif geom_type == "multilinestring":
         return MultiLineString(ob["coordinates"])
     elif geom_type == "multipolygon":
-        return MultiPolygon(ob["coordinates"])
+        return MultiPolygon(ob["coordinates"], context_type='geojson')
     else:
-        raise ValueError, "Unknown geometry type: %s" % geom_type
+        raise ValueError("Unknown geometry type: %s" % geom_type)
 
 def asShape(context):
     """Adapts the context to a geometry interface. The coordinates remain
@@ -46,7 +46,7 @@ def asShape(context):
     try:
         geom_type = ob.get("type").lower()
     except AttributeError:
-        raise ValueError, "Context does not provide geo interface"
+        raise ValueError("Context does not provide geo interface")
 
     if geom_type == "point":
         return asPoint(ob["coordinates"])
@@ -59,6 +59,10 @@ def asShape(context):
     elif geom_type == "multilinestring":
         return asMultiLineString(ob["coordinates"])
     elif geom_type == "multipolygon":
-        return asMultiPolygon(ob["coordinates"])
+        return MultiPolygonAdapter(ob["coordinates"], context_type='geojson')
     else:
-        raise ValueError, "Unknown geometry type: %s" % geom_type
+        raise ValueError("Unknown geometry type: %s" % geom_type)
+
+def mapping(ob):
+    """Returns a GeoJSON-like mapping"""
+    return ob.__geo_interface__
